membrane_performance
====================
Files included for training
::

  train_files:
  - Fov1_DC
  - Fov2_DC
  - Fov3_DC
  - Fov5_DC
  - Fov6_DC

  test_files:
  - Fov7_DC
  - Fov8_DC
  - Fov9_DC
  - Fov10_DC


which to maximise (recall or f)
::

  maximise_choice: 'f'


membrane images
::

  vis_threshold: 0
  vis_interpolate: 'log2'
